@@ -1,10 +1,9 @@
 package Pcore::API::SCM::Server::Hg;
 
-use Pcore -class;
+use Pcore -class, -result;
 use Pcore::API::SCM qw[:CONST];
 use Pcore::Util::Text qw[decode_utf8];
 use Pcore::API::SCM::Upstream;
-use Pcore::API::Response;
 use Pcore::Util::Scalar qw[weaken];
 
 with qw[Pcore::API::SCM::Server];
@@ -125,13 +124,13 @@ sub scm_cmd ( $self, $root, $cb, $cmd ) {
                     $self->_read(__SUB__);
                 }
                 else {
-                    my $api_res = Pcore::API::Response->new( { status => 200 } );
+                    my $api_res;
 
                     if ( exists $res->{e} ) {
-                        $api_res->set_status( 500, join q[ ], $res->{e}->@* );
+                        $api_res = result [ 500, join q[ ], $res->{e}->@* ];
                     }
                     else {
-                        $api_res->{result} = $res->{o};
+                        $api_res = result 200, $res->{o};
                     }
 
                     $cb->($api_res);
@@ -166,7 +165,7 @@ sub scm_id ( $self, $root, $cb, $args ) {
                     release_distance => undef,
                 );
 
-                ( $res{node}, $res{phase}, $res{tags}, $res{bookmark}, $res{branch}, $res{desc}, $res{date}, $res{release} ) = split /\n/sm, $res->{result}->[0];
+                ( $res{node}, $res{phase}, $res{tags}, $res{bookmark}, $res{branch}, $res{desc}, $res{date}, $res{release} ) = split /\n/sm, $res->{data}->[0];
 
                 $res{tags} = $res{tags} ? [ split /\x00/sm, $res{tags} ] : undef;
 
@@ -176,7 +175,7 @@ sub scm_id ( $self, $root, $cb, $args ) {
                     $res{release} = undef if $res{release} eq 'null';
                 }
 
-                $res->{result} = \%res;
+                $res->{data} = \%res;
             }
 
             $cb->($res);
@@ -219,7 +218,7 @@ sub scm_releases ( $self, $root, $cb, $args ) {
         $root,
         sub ($res) {
             if ( $res->is_success ) {
-                $res->{result} = [ sort grep {/\Av\d+[.]\d+[.]\d+\z/sm} $res->{result}->@* ];
+                $res->{data} = [ sort grep {/\Av\d+[.]\d+[.]\d+\z/sm} $res->{data}->@* ];
             }
 
             $cb->($res);
@@ -237,7 +236,7 @@ sub scm_is_commited ( $self, $root, $cb, $args ) {
         $root,
         sub ($res) {
             if ( $res->is_success ) {
-                $res->{result} = defined $res->{result} ? 0 : 1;
+                $res->{data} = defined $res->{data} ? 0 : 1;
             }
 
             $cb->($res);
@@ -289,9 +288,9 @@ sub scm_set_tag ( $self, $root, $cb, $args ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 105, 107, 113        | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |    2 | 104, 106, 112        | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 186                  | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
+## |    1 | 185                  | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
