@@ -1,17 +1,9 @@
-package Pcore::App::Alien::Role;
-
-use Pcore -role;
-
-requires qw[master_proc alien_proc];
-
 package Pcore::App::Alien;
 
 use Pcore -class;
 use POSIX qw[:sys_wait_h];
 
-extends qw[Pcore::App];
-
-with qw[Pcore::App::Alien::Role];
+extends qw[Pcore::App::Base];
 
 has alien_dir      => ( is => 'lazy', isa => Str, init_arg => undef );
 has alien_data_dir => ( is => 'lazy', isa => Str, init_arg => undef );
