@@ -33,6 +33,7 @@ our $DEFAULT = {
 
     useragent         => "Pcore-HTTP/$Pcore::VERSION",
     recurse           => 7,                              # max. redirects
+    keepalive_timeout => undef,                          # keepalive timeout for persistent connections, if false - default value will be used
     timeout           => 300,                            # timeout in seconds
     accept_compressed => 1,                              # add ACCEPT_ENCODIING header
     decompress        => 1,                              # automatically decompress
@@ -202,7 +203,8 @@ sub _request {
         }
     }
 
-    $args{res} = Pcore::HTTP::Response->new;
+    # create empty HTTP response object
+    $args{res} = Pcore::HTTP::Response->new( { status => 0 } );
 
     # resolve cookie_jar shortcut
     $args{cookie_jar} = Pcore::HTTP::CookieJar->new if $args{cookie_jar} && !ref $args{cookie_jar};
@@ -210,17 +212,14 @@ sub _request {
     $args{url} = P->uri( $args{url}, base => 'http://', authority => 1 ) if !ref $args{url};
 
     # set HOST header
-    $args{headers}->{HOST} = $args{url}->host->name unless exists $args{headers}->{HOST};
+    $args{headers}->{HOST} = $args{url}->host->name if !exists $args{headers}->{HOST};
 
     # set REFERER header
-    $args{headers}->{REFERER} = $args{url}->to_string unless exists $args{headers}->{REFERER};
+    $args{headers}->{REFERER} = $args{url}->to_string if !exists $args{headers}->{REFERER};
 
     # set ACCEPT_ENCODING headers
     $args{headers}->{ACCEPT_ENCODING} = 'gzip' if $args{accept_compressed} && !exists $args{headers}->{ACCEPT_ENCODING};
 
-    # set TE header
-    $args{headers}->{TE} = 'trailers';
-
     # add COOKIE headers
     if ( $args{cookie_jar} && ( my $cookies = $args{cookie_jar}->get_cookies( $args{url} ) ) ) {
         $args{headers}->add( COOKIE => join q[; ], $cookies->@* );
@@ -413,14 +412,11 @@ sub _get_on_progress_cb (%args) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 110, 175, 184, 232,  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
-## |      | 233, 254             |                                                                                                                |
+## |    3 | 114                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 113                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 175                  | Subroutines::ProhibitExcessComplexity - Subroutine "_request" with high complexity score (34)                  |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 174                  | Subroutines::ProhibitExcessComplexity - Subroutine "_request" with high complexity score (34)                  |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 160                  | ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    |
+## |    2 | 161                  | ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
