@@ -13,13 +13,17 @@ sub load ( $class, @ ) {
 
     my $class_filename;
 
-    if ( $class =~ /[.]pm\z/sm ) {
+    if ( substr( $class, -3 ) eq '.pm' ) {
         $class_filename = $class;
+
+        $class =~ s[/][::]smg;
+
+        substr $class, -3, 3, q[];
     }
     else {
         $class = resolve_class_name( $class, $args{ns} );
 
-        $class_filename = ( $class =~ s[::][/]smgr ) . q[.pm];
+        $class_filename = ( $class =~ s[::][/]smgr ) . '.pm';
     }
 
     require $class_filename;
@@ -31,6 +35,37 @@ sub load ( $class, @ ) {
     return $class;
 }
 
+sub find ( $class, @ ) {
+    my %args = (
+        ns => undef,
+        splice @_, 1,
+    );
+
+    my $class_filename;
+
+    if ( $class =~ /[.]pm\z/sm ) {
+        $class_filename = $class;
+    }
+    else {
+        $class = resolve_class_name( $class, $args{ns} );
+
+        $class_filename = ( $class =~ s[::][/]smgr ) . q[.pm];
+    }
+
+    my $found;
+
+    # find class in @INC
+    for my $inc ( grep { !ref } @INC ) {
+        if ( -f "$inc/$class_filename" ) {
+            $found = "$inc/$class_filename";
+
+            last;
+        }
+    }
+
+    return $found;
+}
+
 sub resolve_class_name ( $class, $ns = undef ) {
     if ( $class =~ s/\A[+]//sm ) {
         return $class;
